@@ -36,6 +36,10 @@ void        gnome_db_browser_tables_show (GtkWidget *widget,
 void        gnome_db_browser_tables_clear (GtkWidget *widget);
 GtkWidget  *gnome_db_browser_types_new (void);
 GtkWidget  *gnome_db_browser_views_new (void);
+void        gnome_db_browser_views_show (GtkWidget *widget,
+					 GdaConnection *cnc,
+					 const gchar *str);
+void        gnome_db_browser_views_clear (GtkWidget *widget);
 
 G_END_DECLS
 
